==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Tokenization.java <==
package software.amazon.awscdk.core;

/**
 * Less oft-needed functions to manipulate Tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.930Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Tokenization")
public class Tokenization extends software.amazon.jsii.JsiiObject {

    protected Tokenization(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tokenization(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return whether the given object is an IResolvable object.
     * 
     * This is different from Token.isUnresolved() which will also check for
     * encoded Tokens, whereas this method will only do a type check on the given
     * object.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isResolvable(final java.lang.Object obj) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "isResolvable", java.lang.Boolean.class, new Object[] { obj });
    }

    /**
     * Resolves an object by evaluating all tokens and removing any undefined or empty objects or arrays. Values can only be primitives, arrays or tokens. Other objects (i.e. with methods) will be rejected.
     * 
     * @param obj The object to resolve.
     * @param options Prefix key path components for diagnostics.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Object resolve(final java.lang.Object obj, final software.amazon.awscdk.core.ResolveOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "resolve", java.lang.Object.class, new Object[] { obj, java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * Un-encode a Tokenized value from a list.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseList(final java.util.List<java.lang.String> l) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseList", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(l, "l is required") });
    }

    /**
     * Un-encode a Tokenized value from a number.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseNumber(final java.lang.Number n) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseNumber", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(n, "n is required") });
    }

    /**
     * Un-encode a string potentially containing encoded tokens.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.TokenizedStringFragments reverseString(final java.lang.String s) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseString", software.amazon.awscdk.core.TokenizedStringFragments.class, new Object[] { java.util.Objects.requireNonNull(s, "s is required") });
    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/Tokenization.java <==
package software.amazon.awscdk.core;

/**
 * Less oft-needed functions to manipulate Tokens.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.481Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Tokenization")
public class Tokenization extends software.amazon.jsii.JsiiObject {

    protected Tokenization(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Tokenization(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return whether the given object is an IResolvable object.
     * 
     * This is different from Token.isUnresolved() which will also check for
     * encoded Tokens, whereas this method will only do a type check on the given
     * object.
     * 
     * @param obj This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isResolvable(final java.lang.Object obj) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "isResolvable", java.lang.Boolean.class, new Object[] { obj });
    }

    /**
     * Resolves an object by evaluating all tokens and removing any undefined or empty objects or arrays. Values can only be primitives, arrays or tokens. Other objects (i.e. with methods) will be rejected.
     * 
     * @param obj The object to resolve. This parameter is required.
     * @param options Prefix key path components for diagnostics. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Object resolve(final java.lang.Object obj, final software.amazon.awscdk.core.ResolveOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "resolve", java.lang.Object.class, new Object[] { obj, java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * Un-encode a Tokenized value from a list.
     * 
     * @param l This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseList(final java.util.List<java.lang.String> l) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseList", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(l, "l is required") });
    }

    /**
     * Un-encode a Tokenized value from a number.
     * 
     * @param n This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.IResolvable reverseNumber(final java.lang.Number n) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseNumber", software.amazon.awscdk.core.IResolvable.class, new Object[] { java.util.Objects.requireNonNull(n, "n is required") });
    }

    /**
     * Un-encode a string potentially containing encoded tokens.
     * 
     * @param s This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.core.TokenizedStringFragments reverseString(final java.lang.String s) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.core.Tokenization.class, "reverseString", software.amazon.awscdk.core.TokenizedStringFragments.class, new Object[] { java.util.Objects.requireNonNull(s, "s is required") });
    }
}
